<!--
PUBLIC "-//Mark Wroth//DOCUMENT DBLP Weave Print Rules 1.0//EN"

This document is intended to be a minimum DocBook style-sheet
customization layer.
-->
<!DOCTYPE style-sheet
  PUBLIC "-//James Clark//DTD DSSSL Style Sheet//EN" [
 <!ENTITY dbprint.dsl PUBLIC 
   "-//Norman Walsh//DOCUMENT DocBook Print Stylesheet//EN"
   CDATA DSSSL>
 <!ENTITY dbhtml.dsl PUBLIC
   "-//Norman Walsh//DOCUMENT DocBook HTML Stylesheet//EN"
   CDATA DSSSL>
]> 
<style-sheet> 
<style-specification id="print" use="dbprint"> 
<style-specification-body>

(element literalchar
  (make sequence
    (literal (attribute-string "data"))))



(element programlisting (make sequence
  
  (make paragraph
    (make sequence
      font-family-name: scrap-header-font
      font-size:        scrap-header-size
      (literal "\left-pointing-angle-bracket")
      (if (attribute-string "file")
        (literal (attribute-string "file"))
        (if (attribute-string "xreflabel")
          (literal (attribute-string "xreflabel"))
          (with-mode scrap-title-mode
            (make sequence
              (process-element-with-id 
                (attribute-string "continuedfrom"))
              (literal " ")))))
       (make sequence
         font-size: (* scrap-header-size 0.75)
         (literal " (ID: ")
         (literal (attribute-string "id")))
       (literal ")\right-pointing-angle-bracket")
       (if (attribute-string "continuedfrom")
           (literal "+")
           (empty-sosofo))
       (literal "\identical-to")))
  
  
  ($verbatim-display$
   %indent-programlisting-lines%
   %number-programlisting-lines%)
  
  (if (attribute-string "continuedin")
      (make paragraph
        font-family-name: scrap-header-font
        font-size:        scrap-header-size
        (make sequence
          (literal "Continued in ")
          (literal (attribute-string "continuedin"))))
      (empty-sosofo))
   ))


(element (programlisting xref) (make sequence
  font-family-name: scrap-header-font
  font-size:        scrap-header-size
 (literal "\left-pointing-angle-bracket")
 
  (let* ((endterm (attribute-string (normalize "endterm")))
          (linkend (attribute-string (normalize "linkend")))
          (target  (element-with-id linkend))
          (xreflabel (if (node-list-empty? target)
                         #f
                         (attribute-string (normalize "xreflabel") target))))
     (if (node-list-empty? target)
         (error (string-append "XRef LinkEnd to missing ID '" linkend "'"))
         (if xreflabel
             (make link 
               destination: (node-list-address target)
               (literal xreflabel))
             (if endterm
                 (if (node-list-empty? (element-with-id endterm))
                     (error (string-append "XRef EndTerm to missing ID '" 
                                           endterm "'"))
                     (make link 
                       destination: (node-list-address (element-with-id endterm))
                       (with-mode xref-endterm-mode 
                         (process-element-with-id endterm))))
                 (cond
                  ((or (equal? (gi target) (normalize "biblioentry"))
                       (equal? (gi target) (normalize "bibliomixed")))
                   ;; xref to the bibliography is a special case
                   (xref-biblioentry target))
                  ((equal? (gi target) (normalize "co"))
                   ;; callouts are a special case
                   (xref-callout target))
                  ((equal? (gi target) (normalize "listitem"))
                   (xref-listitem target))
                  ((equal? (gi target) (normalize "question"))
                   (xref-question target))
                  ((equal? (gi target) (normalize "answer"))
                   (xref-answer target))
                  ((equal? (gi target) (normalize "refentry"))
                   (xref-refentry target))
                  ((equal? (gi target) (normalize "glossentry"))
                   ;; as are glossentrys
                   (xref-glossentry target))
                  ((equal? (gi target) (normalize "author"))
                   ;; and authors
                   (xref-author target))
                  ((equal? (gi target) (normalize "authorgroup"))
                   ;; and authorgroups
                   (xref-authorgroup target))
                  (else 
                   (xref-general target)))))))
 (literal "\right-pointing-angle-bracket")
))


(define scrap-header-size 8pt)
(define scrap-header-font "Georgia")

(mode scrap-title-mode
  (element programlisting
    (make sequence
      (if (attribute-string "file")
          (literal (attribute-string "file"))
          (empty-sosofo))
      (if (attribute-string "xreflabel")
          (literal (attribute-string "xreflabel"))
          (empty-sosofo)))))




</style-specification-body>
</style-specification>
<style-specification id="html" use="dbhtml"> 
<style-specification-body>

(element literalchar
  (make sequence
    (literal (attribute-string "data"))))



(element programlisting (make sequence
 
 (make element gi: "P"
   (make sequence
     (literal "<")
     (if (attribute-string "file")
       (literal (attribute-string "file"))
       (if (attribute-string "xreflabel")
         (literal (attribute-string "xreflabel"))
         (with-mode scrap-title-mode
           (make sequence
             (process-element-with-id 
               (attribute-string "continuedfrom"))
             (literal " ")))))
      (make sequence
        (literal " (ID: ")
        (literal (attribute-string "id")))
      (literal ")>")
      (if (attribute-string "continuedfrom")
          (literal "+")
          (empty-sosofo))
      (literal "=")))
 
 ($verbatim-display$
 %indent-programlisting-lines%
  %number-programlisting-lines%)
 
 
 (if (attribute-string "continuedin")
     (make element gi: "P"
       (make sequence
         (literal "Continued in ")
         (literal (attribute-string "continuedin"))))
     (empty-sosofo))
))

(element (programlisting xref) (make sequence
(literal "<")

(let* ((endterm   (attribute-string (normalize "endterm")))
         (linkend   (attribute-string (normalize "linkend")))
         (target    (element-with-id linkend))
         (xreflabel (if (node-list-empty? target)
                        #f
                        (attribute-string (normalize "xreflabel") target))))
    (if (node-list-empty? target)
        (error (string-append "XRef LinkEnd to missing ID '" linkend "'"))
        (make element gi: "A"
              attributes: (list
                           (list "HREF" (href-to target)))
              (if xreflabel
                  (literal xreflabel)
                  (if endterm
                      (if (node-list-empty? (element-with-id endterm))
                          (error (string-append
                                  "XRef EndTerm to missing ID '" 
                                  endterm "'"))
                          (with-mode xref-endterm-mode
                            (process-node-list (element-with-id endterm))))
                      (cond
                       ((or (equal? (gi target) (normalize "biblioentry"))
                            (equal? (gi target) (normalize "bibliomixed")))
                        ;; xref to the bibliography is a special case
                        (xref-biblioentry target))
                       ((equal? (gi target) (normalize "co"))
                        ;; callouts are a special case
                        ($callout-mark$ target #f))
                       ((equal? (gi target) (normalize "listitem"))
                        ;; listitems are a special case
                        (if (equal? (gi (parent target)) (normalize "orderedlist"))
                            (literal (orderedlist-listitem-label-recursive target))
                            (error (string-append "XRef to LISTITEM only supported in ORDEREDLISTs"))))
                       ((equal? (gi target) (normalize "question"))
                        ;; questions and answers are (yet another) special case
                        (make sequence
                          (literal (gentext-element-name target))
                          (literal (gentext-label-title-sep target))
                          (literal (question-answer-label target))))
                       ((equal? (gi target) (normalize "answer"))
                        ;; questions and answers are (yet another) special case
                        (make sequence
                          (literal (gentext-element-name target))
                          (literal (gentext-label-title-sep target))
                          (literal (question-answer-label target))))
                       ((equal? (gi target) (normalize "refentry"))
                        ;; so are refentrys
                        (xref-refentry target))
                       ((equal? (gi target) (normalize "glossentry"))
                        ;; as are glossentrys
                        (xref-glossentry target))
                       ((equal? (gi target) (normalize "author"))
                        ;; and authors
                        (xref-author target))
                       ((equal? (gi target) (normalize "authorgroup"))
                        ;; and authorgroups
                        (xref-authorgroup target))
; this doesn't really work very well yet
;                      ((equal? (gi target) (normalize "substeps"))
;                       ;; and substeps
;                       (xref-substeps target))
                       (else 
                        (xref-general target))))))))
(literal ">")
))


(mode scrap-title-mode
  (element programlisting
    (make sequence
      (if (attribute-string "file")
          (literal (attribute-string "file"))
          (empty-sosofo))
      (if (attribute-string "xreflabel")
          (literal (attribute-string "xreflabel"))
          (empty-sosofo)))))




</style-specification-body>
</style-specification>
<external-specification id="dbprint" document="dbprint.dsl">
<external-specification id="dbhtml" document="dbhtml.dsl">
</style-sheet>
